{% extends 'admin/base_site.html' %}
{% load i18n %}
{% block content %}
<h1>{% trans "Create A New Filter" %}</h1>

 <form action="" method="post">
    {% csrf_token %}
    <table>
        {{ form.as_table }}
    </table>
    <table>
        <thead><tr><th>Filter Parameter</th></tr></thead>
        {{ query_form.as_table }}
    </table>
    <input type="submit" name="apply" value="{% trans "Apply" %}" />
    <input type="submit" name="save" value="{% trans "Save and apply" %}" />
</form>
{% endblock %}
